@@ -38,6 +38,21 @@ function test_bluer_algo_help() {
         \
         "@algo tracker" \
         \
+        "@algo bps" \
+        "@bps" \
+        "@bps beacon" \
+        "@bps generate" \
+        "@bps install" \
+        "@bps introspect" \
+        "@bps loop" \
+        "@bps loop start" \
+        "@bps loop stop" \
+        "@bps receiver" \
+        "@bps review" \
+        "@bps simulate" \
+        "@bps simulate timing" \
+        "@bps test_bluetooth" \
+        \
         "@image_classifier" \
         "@image_classifier dataset" \
         "@image_classifier dataset ingest" \
