@@ -1,12 +1,19 @@
 from bluer_objects import README
+from bluer_objects.README.consts import assets2
 
 
 items = README.Items(
     [
+        {
+            "name": "bps",
+            "description": "bluer-positioning system.",
+            "marquee": f"{assets2}/bps/02.png?raw=true",
+            "url": "./bluer_algo/docs/bps",
+        },
         {
             "name": "yolo",
             "description": "a yolo interface.",
-            "marquee": "https://github.com/kamangir/assets/raw/main/coco128-2025-08-14-myrsky/review.png?raw=true",
+            "marquee": "https://github.com/kamangir/assets/raw/main/swallow-debug-2025-09-16-19-53-19-4yzsp8/swallow-debug-2025-09-16-19-53-19-4yzsp8-2.gif?raw=true",
             "url": "./bluer_algo/docs/yolo",
         },
         {
